---
title: Variable assignment
tldr: "`a=1` is an example of variable assignment."
---

In Python operator `=` is used to assign, or 'bind', a value to a variable.

## Suggested reading

- <https://greenteapress.com/thinkpython2/html/thinkpython2003.html#sec16>
- <https://jakevdp.github.io/WhirlwindTourOfPython/03-semantics-variables.html>
